@@ -1,3 +1,30 @@
+.get_model_function <- function(model) {
+  # check class of fitted model
+  lm_models <- c(
+    "wblm", "wbm", "biglm", "speedlm", "gls", "ols", "ivreg", "gee", "plm", "lm",
+    "rqss", "lmRob", "lm_robust", "lme", "truncreg", "nlmerMod", "glmgee",
+    "lmerMod", "merModLmerTest", "rlmerMod", "bayesx", "mclogit"
+  )
+
+  info <- insight::model_info(model, verbose = FALSE)
+  if (insight::is_multivariate(model) && !inherits(model, c("vglm", "vgam"))) {
+    info <- info[[1]]
+  }
+
+  if (inherits(model, lm_models) && !inherits(model, "glm")) {
+    "lm"
+  } else if (inherits(model, "coxph")) {
+    "coxph"
+  } else if (inherits(model, "betareg")) {
+    "betareg"
+  } else if (isTRUE(info$is_linear)) {
+    "lm"
+  } else {
+    "glm"
+  }
+}
+
+
 .data_frame <- function(...) {
   x <- data.frame(..., stringsAsFactors = FALSE)
   rownames(x) <- NULL
@@ -19,12 +46,18 @@
   out_msg <- NULL
   msg <- tryCatch(
     {
-      pv <- insight::find_predictors(model, effects = "all", component = "all", flatten = TRUE)
+      pv <- insight::find_predictors(
+        model,
+        effects = "all",
+        component = "all",
+        flatten = TRUE,
+        verbose = FALSE
+      )
       clean.terms <- .clean_terms(terms)
       if (!all(clean.terms %in% pv)) {
         out_msg <- c(
           "Some of the specified `terms` were not found in the model.",
-          .misspelled_string(pv, clean.terms, "Maybe misspelled?")
+          .misspelled_string(pv, clean.terms, "Maybe misspelled?")$msg
         )
       }
       out_msg
@@ -41,24 +74,26 @@
 
 
 .offset_term <- function(model, condition = NULL, verbose = TRUE) {
-  tryCatch({
-    off <- insight::safe_deparse(model$call$offset)
-    if (identical(off, "NULL")) {
-      return(NULL)
+  tryCatch(
+    {
+      off <- insight::safe_deparse(model$call$offset)
+      if (identical(off, "NULL")) {
+        return(NULL)
+      }
+      cleaned_off <- insight::clean_names(off)
+      if (!identical(off, cleaned_off) && isTRUE(verbose) && !inherits(model, "glmmTMB") && !cleaned_off %in% names(condition)) { # nolint
+        insight::format_alert(
+          "Model uses a transformed offset term. Predictions may not be correct.",
+          sprintf("It is recommended to fix the offset term using the `condition` argument, e.g. `condition = c(%s = 1)`.", cleaned_off), # nolint
+          sprintf("You could also transform the offset variable before fitting the model and use `offset(%s)` in the model formula.", cleaned_off) # nolint
+        )
+      }
+      cleaned_off
+    },
+    error = function(e) {
+      NULL
     }
-    cleaned_off <- insight::clean_names(off)
-    if (!identical(off, cleaned_off) && isTRUE(verbose) && !inherits(model, "glmmTMB") && !cleaned_off %in% names(condition)) { # nolint
-      insight::format_alert(
-        "Model uses a transformed offset term. Predictions may not be correct.",
-        sprintf("It is recommended to fix the offset term using the `condition` argument, e.g. `condition = c(%s = 1)`.", cleaned_off), # nolint
-        sprintf("You could also transform the offset variable before fitting the model and use `offset(%s)` in the model formula.", cleaned_off) # nolint
-      )
-    }
-    cleaned_off
-  },
-  error = function(e) {
-    NULL
-  })
+  )
 }
 
 
@@ -78,11 +113,9 @@
   }
 
   # add rownames, for labelling data points in plots
-  if (isTRUE(insight::check_if_installed("datawizard", quietly = TRUE))) {
-    .safe({
-      mf <- datawizard::rownames_as_column(mf)
-    })
-  }
+  .safe({
+    mf <- datawizard::rownames_as_column(mf)
+  })
 
   # sanity check, make sure we have rownames as variable
   if (is.null(mf$rowname)) {
@@ -205,29 +238,18 @@ is.whole.number <- function(x) {
 }
 
 
-.get_poly_term <- function(x) {
-  p <- "(.*)poly\\(([^,]*)[^)]*\\)(.*)"
-  sub(p, "\\2", x)
-}
-
-
-.get_poly_degree <- function(x) {
-  p <- "(.*)poly\\(([^,]*)([^)])*\\)(.*)"
-  tryCatch(as.numeric(sub(p, "\\3", x)), error = function(x) 1)
-}
-
-
 is_brms_trial <- function(model) {
   is.trial <- FALSE
 
   if (inherits(model, "brmsfit") && is.null(stats::formula(model)$responses)) {
-    is.trial <- tryCatch({
-      rv <- insight::safe_deparse(stats::formula(model)$formula[[2L]])
-      trimws(sub("(.*)\\|(.*)\\(([^,)]*).*", "\\2", rv)) %in% c("trials", "resp_trials")
-    },
-    error = function(x) {
-      FALSE
-    }
+    is.trial <- tryCatch(
+      {
+        rv <- insight::safe_deparse(stats::formula(model)$formula[[2L]])
+        trimws(sub("(.*)\\|(.*)\\(([^,)]*).*", "\\2", rv)) %in% c("trials", "resp_trials")
+      },
+      error = function(x) {
+        FALSE
+      }
     )
   }
 
@@ -252,7 +274,7 @@ is_brms_trial <- function(model) {
     x <- x[stats::complete.cases(x), ]
   }
   x[!vapply(x, function(i) {
-    !insight::is_model(i) && (length(i) == 0 || is.null(i) || (!is.function(i) && any(i == "NULL", na.rm = TRUE)))
+    !insight::is_model(i) && (length(i) == 0 || is.null(i) || (!is.function(i) && any(as.character(i) == "NULL", na.rm = TRUE)))
   }, TRUE)]
 }
 
@@ -291,7 +313,9 @@ is.gamm4 <- function(x) {
 # remove column
 .remove_column <- function(data, variables) {
   a <- attributes(data)
-  if (!length(variables) || is.null(variables)) return(data)
+  if (!length(variables) || is.null(variables)) {
+    return(data)
+  }
   if (is.numeric(variables)) variables <- colnames(data)[variables]
   data <- data[, -which(colnames(data) %in% variables), drop = FALSE]
   remaining <- setdiff(names(a), names(attributes(data)))
@@ -423,7 +447,7 @@ is.gamm4 <- function(x) {
         )
         possible_strings <- possible_strings[1:5]
       }
-      msg <- paste0(msg, "one of ", toString(paste0("\"", possible_strings, "\"")))
+      msg <- paste0(msg, "one of ", datawizard::text_concatenate(possible_strings, last = " or ", enclose = "\""))
     } else {
       msg <- paste0(msg, "\"", possible_strings, "\"")
     }
@@ -432,7 +456,7 @@ is.gamm4 <- function(x) {
     msg <- default_message
   }
   # no double white space
-  insight::trim_ws(msg)
+  list(msg = insight::trim_ws(msg), possible_strings = possible_strings)
 }
 
 
